// ************************************************************************************************************
// OLED Functions
// ************************************************************************************************************
void sendcommand(unsigned char com)
{
  i2c_OLED_send_cmd(com);  
}

//==========================================================//
void print_a_char(unsigned char ascii=0)
{
  unsigned char i=0;
  for(i=0;i<8;i++) { SendChar(myFont[ascii-0x20][i]); }
}

//==========================================================//
void clear_display(void)
{
  i2c_OLED_send_cmd(0xa6);              //Set Normal Display
  i2c_OLED_send_cmd(0xae);              // Display OFF
  i2c_OLED_send_cmd(0x20);              // Set Memory Addressing Mode
  i2c_OLED_send_cmd(0x00);              // Set Memory Addressing Mode to Horizontal addressing mode
  i2c_OLED_send_cmd(0xb0);              // set page address to 0
  i2c_OLED_send_cmd(0X40);              // Display start line register to 0
  i2c_OLED_send_cmd(0);                 // Set low col address to 0
  i2c_OLED_send_cmd(0x10);              // Set high col address to 0
  for(uint16_t i=0; i<1024; i++)        // fill the display's RAM with graphic... 128*64 pixel picture
  {
     i2c_OLED_send_byte(0);  // clear
  }
  i2c_OLED_send_cmd(0x81);              // Setup CONTRAST CONTROL, following byte is the contrast Value... always a 2 byte instruction
  i2c_OLED_send_cmd(0xff);               // Here you can set the brightness 1 = dull, 255 is very bright
  i2c_OLED_send_cmd(0xaf);              // display on
}

//==========================================================//
void SendChar(unsigned char data)
{
  i2c_OLED_send_byte(data);
}

//==========================================================//
void setXY(unsigned char row,unsigned char col)
{
  sendcommand(0xb0+row);                //set page address
  sendcommand(0x00+(8*col&0x0f));       //set low col address
  sendcommand(0x10+((8*col>>4)&0x0f));  //set high col address
}

void setPixYX(unsigned char row,unsigned char col)
{
  sendcommand(0xb0+row);                //set page address 0xb0 = 10110000 => set adress 0 (haut de l'écran)
  sendcommand(0x00+(col&0x0f));         //set low col address
  sendcommand(0x10+((col>>4)&0x0f));    //set high col address
}

void  bgraphe(byte frame, byte thickness, byte value) // Fr : Frame 0 to 7, Th : Thickness between 1,2 and 3, value 0 to ? but anti sat to 127
// by default, the start col is 48 pixel (6 characters with 8 pixel large)
{
  constrain(value,REF_XBG,127);
  switch (thickness) {
    case 1:
    thickness = 24;
    break;
    case 2:
    thickness = 60;
    break;
    case 3:
    thickness = 126;
    break;
    default:
    thickness = 60;
    break;
  }
  for (byte i=REF_XBG; i<value; i++)
 {
   setPixYX(frame,i);
   i2c_OLED_send_byte(thickness);
   
 }
   for (byte i=value; i<=127; i++)
 {
   setPixYX(frame,i);
   i2c_OLED_send_byte(0);
 }
}

void  pointXY(byte X, byte Y) // limit mini 0 maxi 55
{
  constrain(X,0,127); constrain(Y,0,63);
  byte frame;
  if (Y<8) { frame=7; Y=7-Y; }
  else if (Y<16) { frame=6; Y=15-Y; }
  else if (Y<24) { frame=5; Y=23-Y; }
  else if (Y<32) { frame=4; Y=31-Y; }
  else if (Y<40) { frame=3; Y=39-Y; }
  else if (Y<48) { frame=2; Y=47-Y; }
  else if (Y<56) { frame=1; Y=55-Y; }
  else if (Y<64) { frame=0; Y=63-Y; }
  switch (Y) {
    case 0:
      Y=1;
      break;
    case 1:
      Y=2;
      break;
    case 2:
      Y=4;
      break;
    case 3:
      Y=8;
      break;
    case 4:
      Y=16;
      break;
    case 5:
      Y=32;
      break;
    case 6:
      Y=64;
      break;
    case 7:
      Y=128;
      break;
    }
    setPixYX(frame,X+REF_X);
    delayMicroseconds(100);
    i2c_OLED_send_byte(Y);
}

//==========================================================//
void sendStr(unsigned char *string)
{
  unsigned char i=0;
  //setXY(0,0);    
  while(*string)
  {
    for(i=0;i<8;i++)
    {
      SendChar(myFont[*string-0x20][i]);

      // SendChar(*string);
      delay(3);
    }
    *string++;
  }
}

//==========================================================//
void init_OLED(void)
{
i2c_OLED_init();
}

void  i2c_OLED_init(void){
  i2c_OLED_send_cmd(0xae);    //display off
  i2c_OLED_send_cmd(0x2e);    //deactivate scrolling
  i2c_OLED_send_cmd(0xa4);          //SET All pixels OFF
//  i2c_OLED_send_cmd(0xa5);            //SET ALL pixels ON
  delay(50);
  i2c_OLED_send_cmd(0x20);            //Set Memory Addressing Mode
  i2c_OLED_send_cmd(0x02);            //Set Memory Addressing Mode to Page addressing mode(RESET)
//  i2c_OLED_send_cmd(0xa0);      //colum address 0 mapped to SEG0 (POR)*** wires at bottom
  i2c_OLED_send_cmd(0xa1);    //colum address 127 mapped to SEG0 (POR) ** wires at top of board
//  i2c_OLED_send_cmd(0xC0);            // Scan from Right to Left (POR)         *** wires at bottom
  i2c_OLED_send_cmd(0xC8);          // Scan from Left to Right               ** wires at top
  i2c_OLED_send_cmd(0xa6);            // Set WHITE chars on BLACK backround

//  i2c_OLED_send_cmd(0xa7);            // Set BLACK chars on WHITE backround
  i2c_OLED_send_cmd(0x81);            // 81 Setup CONTRAST CONTROL, following byte is the contrast Value
  i2c_OLED_send_cmd(0xff);            // af contrast value between 1 ( == dull) to 256 ( == bright)
  delay(20);
  i2c_OLED_send_cmd(0xaf);          //display on
  delay(20);
}



